@@ -112,6 +112,9 @@ namespace KSysGuard
       inline bool readProcStat(const QString &dir, Process *process);
       inline bool readProcStatm(const QString &dir, Process *process);
       inline bool readProcCmdline(const QString &dir, Process *process);
+      inline bool readProcCGroup(const QString &dir, Process *process);
+      inline bool readProcAttr(const QString &dir, Process *process);
+      inline bool readProcSmaps(const QString &dir, Process *process);
       inline bool getNiceness(long pid, Process *process);
       inline bool getIOStatistics(const QString &dir, Process *process);
       QFile mFile;
@@ -200,6 +203,35 @@ bool ProcessesLocal::Private::readProcStatus(const QString &dir, Process *proces
     return true;
 }
 
+bool ProcessesLocal::Private::readProcCGroup(const QString &dir, Process *process)
+{
+    mFile.setFileName(dir + QStringLiteral("cgroup"));
+    if(!mFile.open(QIODevice::ReadOnly))
+        return false;      /* process has terminated in the meantime */
+
+    while( mFile.readLine( mBuffer, sizeof(mBuffer)) > 0) {  //-1 indicates an error
+	    if ( mBuffer[0] == '0' && mBuffer[1] == ':' && mBuffer[2] == ':' ) {
+	       process->setCGroup(QString::fromLocal8Bit(&mBuffer[3]).trimmed());
+	       break;
+	    }
+    }
+    mFile.close();
+    return true;
+}
+
+bool ProcessesLocal::Private::readProcAttr(const QString &dir, Process *process)
+{
+    mFile.setFileName(dir + QStringLiteral("attr/current"));
+    if(!mFile.open(QIODevice::ReadOnly))
+        return false;      /* process has terminated in the meantime */
+
+    if( mFile.readLine( mBuffer, sizeof(mBuffer)) > 0) {  //-1 indicates an error
+        process->setMACContext(QString::fromLocal8Bit(mBuffer).trimmed());
+    }
+    mFile.close();
+    return true;
+}
+
 long ProcessesLocal::getParentPid(long pid) {
     if (pid <= 0)
         return -1;
@@ -424,6 +456,27 @@ bool ProcessesLocal::Private::readProcCmdline(const QString &dir, Process *proce
     return true;
 }
 
+bool ProcessesLocal::Private::readProcSmaps(const QString &dir, Process *process)
+{
+    mFile.setFileName(dir + QStringLiteral("smaps_rollup"));
+    if (!mFile.open(QIODevice::ReadOnly)) {
+        return false;
+    }
+
+    auto totalPss = -1LL;
+    while (mFile.readLine(mBuffer, sizeof(mBuffer)) > 0) {
+        if (qstrncmp(mBuffer, "Pss:", strlen("Pss:")) == 0) {
+            totalPss += atoll(mBuffer + sizeof("Pss:") - 1);
+        }
+    }
+
+    mFile.close();
+
+    process->setVmPSS(totalPss);
+
+    return true;
+}
+
 bool ProcessesLocal::Private::getNiceness(long pid, Process *process) {
   int sched = sched_getscheduler(pid);
   switch(sched) {
@@ -519,11 +572,14 @@ bool ProcessesLocal::Private::getIOStatistics(const QString &dir, Process *proce
 bool ProcessesLocal::updateProcessInfo( long pid, Process *process)
 {
     bool success = true;
-    QString dir = QStringLiteral("/proc/") + QString::number(pid) + QLatin1Char('/');
+    QString dir = QLatin1String("/proc/") + QString::number(pid) + QLatin1Char('/');
     if(!d->readProcStat(dir, process)) success = false;
     if(!d->readProcStatus(dir, process)) success = false;
     if(!d->readProcStatm(dir, process)) success = false;
     if(!d->readProcCmdline(dir, process)) success = false;
+    if(!d->readProcCGroup(dir, process)) success = false;
+    if(!d->readProcAttr(dir, process)) success = false;
+    if(!d->readProcSmaps(dir, process)) success = false;
     if(!d->getNiceness(pid, process)) success = false;
     if(mUpdateFlags.testFlag(Processes::IOStatistics) && !d->getIOStatistics(dir, process)) success = false;
 
